@@ -173,49 +173,33 @@ def open_ini(filePath):
     config.read(filePath)
     return config
 
-# # 创建IPV4节点
-# def create_IPV4(sourceIP: str, sourceMask: int, destinationIP: str, destinationMask: int, TOS: str, action: int):
-#     # 创建ipv4节点
-#     ipv4_node = xt.create_node("ipv4", {}, {})
-#     children_node_Map = {"src": "", "smask": sourceMask, "dst": "", "dmask": destinationMask, "tos": "",
-#                          "path_id": action}
-#     properties = {}
-#     # ===============src================== #
-#     if sourceIP == "any":
-#         properties["src"] = {"any": 1}
-#     elif isIP(sourceIP):
-#         children_node_Map["src"] = sourceIP
-#     else:
-#         return RuntimeError(r"sourceIP必须输入'any'或ipv4地址")
-#     # ===============src mask================== #
-#     if sourceMask not in [32, 24, 16, 8]:
-#         return RuntimeError("sourceIP掩码必须为32、24、16、8中的一个")
-#     # ===============dst================== #
-#     if destinationIP == "any":
-#         properties["dst"] = {"any": 1}
-#     elif isIP(destinationIP):
-#         children_node_Map["dst"] = destinationIP
-#     else:
-#         return RuntimeError(r"destinationIP必须输入'any'或ipv4地址")
-#     # ===============dst mask================== #
-#     if destinationMask not in [32, 24, 16, 8]:
-#         return RuntimeError("destinationIP掩码必须为32、24、16、8中的一个")
-#     # ===============tos================== #
-#     if TOS == "any":
-#         properties["tos"] = {"any": 1}
-#     elif isDoubleHexadecimal(TOS):
-#         children_node_Map["tos"] = TOS
-#     else:
-#         return RuntimeError(r"TOS必须输入'any'或2位十六进制")
-#     # ===============action================== #
-#     paths_dic = get_paths_from_engine(holowan_ip, holowan_port, engineID)
-#     if action not in [-1, -2] and action not in paths_dic.keys():
-#         return RuntimeError("action值输入错误")
-#
-#     xt.add_children(ipv4_node, children_node_Map)
-#     xt.add_properties(ipv4_node, properties)
+# 读取ini文件
+def open_ini2(filePath, section):
+    config = MyConfigParser()
+    config.setSection(section)
+    config.read(filePath)
+    return config
 
+class MyConfigParser(ConfigParser):
+    def __int__(self, section: str):
+        ConfigParser.__init__(self)
+        self.section = section
+
+    def setSection(self, section: str):
+        self.section = section
+
+    def getOption(self, option: str):
+        return super(ConfigParser, self).get(self.section, option)
 
 if __name__ == '__main__':
-    pass
+    project_path = os.path.abspath(os.path.dirname(os.path.dirname(__file__)))
+    ini = open_ini(project_path + r"/holowan/resources/Holowan.ini")
+    print(ini.get("PathOperateErrorCode", "engineIDError"))
+
+
+    ini2 = open_ini2(project_path + r"/holowan/resources/Holowan.ini", "PathOperateErrorCode")
+    print("ini2 PathOperateErrorCode" + ini2.getOption("engineIDError"))
+    ini2.setSection("PathConfigErrorCode")
+    print("ini2 PathConfigErrorCode" + ini2.getOption("engineIDError"))
+
 
